# SPDX-License-Identifier: AGPL-3.0-or-later
# Copyright (C) 2021 Andrew Rechnitzer
# Copyright (C) 2022 Colin B. Macdonald

from plom.scan import with_scanner_messenger


@with_scanner_messenger
def get_bundle_list(*, msgr):
    return msgr.listBundles()


@with_scanner_messenger
def print_bundle_list(*, msgr):
    bundle_list = msgr.listBundles()
    if len(bundle_list) == 0:
        print("No bundles in database.")
        return

    bundle_list.sort(key=lambda X: X["name"])

    head = ["Name", "no. Pages", "md5sum"]
    print(f"{head[0]:40} | {head[1]:10} | {head[2]:32}")
    for X in bundle_list:
        if X["name"] == "__replacements__system__":
            print("-" * 90)
            print(
                "vvvvvvvv This bundle is autogenerated for plom system use only. vvvvvvvv"
            )
        #
        if X["md5sum"] is None:
            X["md5sum"] = "None"
        print(f"{X['name']:40} | {X['numberOfPages']:10} | {X['md5sum']:32}")
        #
        if X["name"] == "__replacements__system__":
            print("-" * 90)
